package fr.uca.iut.clfreville2.teaiswarm

import android.content.Intent
import android.os.Bundle
import android.widget.TextView
import androidx.appcompat.app.AppCompatActivity
import androidx.lifecycle.lifecycleScope
import androidx.recyclerview.widget.RecyclerView
import fr.uca.iut.clfreville2.teaiswarm.model.RepositoryIdentifier
import fr.uca.iut.clfreville2.teaiswarm.model.VersionedFile
import fr.uca.iut.clfreville2.teaiswarm.network.GiteaService
import kotlinx.coroutines.launch

const val FILE_PATH = "file_path"

class RepositoryDetailActivity : AppCompatActivity() {

    private val service = GiteaService()
    private lateinit var repositoryName: TextView
    private lateinit var versionedFiles: RecyclerView

    private lateinit var currentRepositoryOwner: String
    private lateinit var currentRepositoryName: String
    private var currentFilePath: String? = null

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_repository_detail)

        repositoryName = findViewById(R.id.repository_detail_name)

        val bundle: Bundle? = intent.extras
        if (bundle != null) {
            currentRepositoryOwner = bundle.getString(REPOSITORY_OWNER)!!
            currentRepositoryName = bundle.getString(REPOSITORY_NAME)!!
            currentFilePath = bundle.getString(FILE_PATH)
        }

        repositoryName.text = currentRepositoryName

        versionedFiles = findViewById(R.id.versioned_files_view)
        lifecycleScope.launch {
            val repos = service.listFileContents(RepositoryIdentifier(currentRepositoryOwner, currentRepositoryName), currentFilePath ?: "")
            versionedFiles.adapter = FileListAdapter(repos) {
                file -> adapterOnClick(file)
            }
        }
    }

    private fun adapterOnClick(file: VersionedFile) {
        val intent = Intent(this, RepositoryDetailActivity()::class.java)
        intent.putExtra(REPOSITORY_OWNER, currentRepositoryOwner)
        intent.putExtra(REPOSITORY_NAME, currentRepositoryName)
        intent.putExtra(FILE_PATH, (currentFilePath ?: "") + file.name)
        startActivity(intent)
    }
}
